@@ -39,7 +39,7 @@
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: OutputTestCase.php 4404 2008-12-31 09:27:18Z sb $
+ * @version    SVN: $Id: OutputTestCase.php 5135 2009-08-27 08:37:36Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 3.0.0
  */
@@ -57,7 +57,7 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.3.16
+ * @version    Release: 3.4.5
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 3.0.0
  */
@@ -78,6 +78,11 @@ abstract class PHPUnit_Extensions_OutputTestCase extends PHPUnit_Framework_TestC
      */
     protected $output = '';
 
+    /**
+     * @var    boolean
+     */
+    protected $obActive = FALSE;
+
     /**
      * @var    mixed
      */
@@ -111,7 +116,11 @@ abstract class PHPUnit_Extensions_OutputTestCase extends PHPUnit_Framework_TestC
      */
     public function getActualOutput()
     {
-        return $this->output;
+        if (!$this->obActive) {
+            return $this->output;
+        } else {
+            return ob_get_contents();
+        }
     }
 
     /**
@@ -128,7 +137,7 @@ abstract class PHPUnit_Extensions_OutputTestCase extends PHPUnit_Framework_TestC
     public function expectOutputRegex($expectedRegex)
     {
         if ($this->expectedString !== NULL) {
-            throw new RuntimeException;
+            throw new PHPUnit_Framework_Exception;
         }
 
         if (is_string($expectedRegex) || is_null($expectedRegex)) {
@@ -150,7 +159,7 @@ abstract class PHPUnit_Extensions_OutputTestCase extends PHPUnit_Framework_TestC
     public function expectOutputString($expectedString)
     {
         if ($this->expectedRegex !== NULL) {
-            throw new RuntimeException;
+            throw new PHPUnit_Framework_Exception;
         }
 
         if (is_string($expectedString) || is_null($expectedString)) {
@@ -159,17 +168,21 @@ abstract class PHPUnit_Extensions_OutputTestCase extends PHPUnit_Framework_TestC
     }
 
     /**
+     * @return mixed
+     * @throws RuntimeException
      */
     protected function runTest()
     {
         ob_start();
+        $this->obActive = TRUE;
 
         try {
-            parent::runTest();
+            $testResult = parent::runTest();
         }
 
         catch (Exception $e) {
             ob_end_clean();
+            $this->obActive = FALSE;
             throw $e;
         }
 
@@ -180,6 +193,7 @@ abstract class PHPUnit_Extensions_OutputTestCase extends PHPUnit_Framework_TestC
         }
 
         ob_end_clean();
+        $this->obActive = FALSE;
 
         if ($this->expectedRegex !== NULL) {
             $this->assertRegExp($this->expectedRegex, $this->output);
@@ -190,6 +204,8 @@ abstract class PHPUnit_Extensions_OutputTestCase extends PHPUnit_Framework_TestC
             $this->assertEquals($this->expectedString, $this->output);
             $this->expectedString = NULL;
         }
+
+        return $testResult;
     }
 }
 ?>
