@@ -39,7 +39,7 @@
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: PhptTestSuite.php 4404 2008-12-31 09:27:18Z sb $
+ * @version    SVN: $Id: PhptTestSuite.php 4403 2008-12-31 09:26:51Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 3.1.4
  */
@@ -58,7 +58,7 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.3.16
+ * @version    Release: 3.4.5
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 3.1.4
  */
@@ -72,9 +72,9 @@ class PHPUnit_Extensions_PhptTestSuite extends PHPUnit_Framework_TestSuite
      *                         key being the name if the setting, value the ini value.
      * @throws InvalidArgumentException
      */
-    public function __construct($directory, $options = array())
+    public function __construct($directory, array $options = array())
     {
-        if (is_dir($directory)) {
+        if (is_string($directory) && is_dir($directory)) {
             $this->setName($directory);
 
             $iterator = new PHPUnit_Util_FilterIterator(
@@ -88,7 +88,7 @@ class PHPUnit_Extensions_PhptTestSuite extends PHPUnit_Framework_TestSuite
                 $this->addTestFile($testFile->getPathname(), TRUE, $options);
             }
         } else {
-            throw new InvalidArgumentException;
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'directory name');
         }
     }
 }
