@@ -39,7 +39,7 @@
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: Driver.php 4519 2009-01-21 09:47:33Z sb $
+ * @version    SVN: $Id: Driver.php 5307 2009-11-06 08:15:44Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 3.3.0
  */
@@ -56,7 +56,7 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.3.16
+ * @version    Release: 3.4.5
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 3.3.0
  */
@@ -105,7 +105,12 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
     /**
      * @var    integer
      */
-    protected $timeout = 30000;
+    protected $httpTimeout = 45;
+
+    /**
+     * @var    integer
+     */
+    protected $seleniumTimeout = 30;
 
     /**
      * @var    array
@@ -127,13 +132,35 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
      */
     protected $wait = 5;
 
+    /**
+     * @var array
+     */
+    protected static $autoGeneratedCommands = array();
+
+    /**
+     * @var array
+     */
+    protected $commands = array();
+
+    /**
+     * @var array
+     */
+    protected $verificationErrors = array();
+
+    public function __construct()
+    {
+        if (empty(self::$autoGeneratedCommands)) {
+            self::autoGenerateCommands();
+        }
+    }
+
     /**
      * @return string
      */
     public function start()
     {
         if ($this->browserUrl == NULL) {
-            throw new RuntimeException(
+            throw new PHPUnit_Framework_Exception(
               'setBrowserUrl() needs to be called before start().'
             );
         }
@@ -144,7 +171,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
               array($this->browser, $this->browserUrl)
             );
 
-            $this->doCommand('setTimeout', array($this->timeout));
+            $this->doCommand('setTimeout', array($this->seleniumTimeout * 1000));
         }
 
         return $this->sessionId;
@@ -170,7 +197,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
     public function setCollectCodeCoverageInformation($flag)
     {
         if (!is_bool($flag)) {
-            throw new InvalidArgumentException;
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'boolean');
         }
 
         $this->collectCodeCoverageInformation = $flag;
@@ -199,7 +226,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
     public function setName($name)
     {
         if (!is_string($name)) {
-            throw new InvalidArgumentException;
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'string');
         }
 
         $this->name = $name;
@@ -212,7 +239,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
     public function setBrowser($browser)
     {
         if (!is_string($browser)) {
-            throw new InvalidArgumentException;
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'string');
         }
 
         $this->browser = $browser;
@@ -225,7 +252,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
     public function setBrowserUrl($browserUrl)
     {
         if (!is_string($browserUrl)) {
-            throw new InvalidArgumentException;
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'string');
         }
 
         $this->browserUrl = $browserUrl;
@@ -238,7 +265,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
     public function setHost($host)
     {
         if (!is_string($host)) {
-            throw new InvalidArgumentException;
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'string');
         }
 
         $this->host = $host;
@@ -251,23 +278,36 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
     public function setPort($port)
     {
         if (!is_int($port)) {
-            throw new InvalidArgumentException;
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'integer');
         }
 
         $this->port = $port;
     }
 
     /**
-     * @param  integer $timeout
+     * @param  integer $timeout for Selenium RC in seconds
      * @throws InvalidArgumentException
      */
     public function setTimeout($timeout)
     {
         if (!is_int($timeout)) {
-            throw new InvalidArgumentException;
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'integer');
         }
 
-        $this->timeout = $timeout;
+        $this->seleniumTimeout = $timeout;
+    }
+
+    /**
+     * @param  integer $timeout for HTTP connection to Selenium RC in seconds
+     * @throws InvalidArgumentException
+     */
+    public function setHttpTimeout($timeout)
+    {
+        if (!is_int($timeout)) {
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'integer');
+        }
+
+        $this->httpTimeout = $timeout;
     }
 
     /**
@@ -277,7 +317,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
     public function setSleep($seconds)
     {
         if (!is_int($seconds)) {
-            throw new InvalidArgumentException;
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'integer');
         }
 
         $this->sleep = $seconds;
@@ -293,7 +333,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
     public function setWait($seconds)
     {
         if (!is_int($seconds)) {
-            throw new InvalidArgumentException;
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'integer');
         }
 
         $this->wait = $seconds;
@@ -309,7 +349,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
     public function setWaitForPageToLoad($flag)
     {
         if (!is_bool($flag)) {
-            throw new InvalidArgumentException;
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(1, 'boolean');
         }
 
         $this->useWaitForPageToLoad = $flag;
@@ -322,21 +362,33 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
      * @param  array  $arguments
      * @return mixed
      * @method unknown  addLocationStrategy()
+     * @method unknown  addLocationStrategyAndWait()
+     * @method unknown  addScript()
+     * @method unknown  addScriptAndWait()
      * @method unknown  addSelection()
      * @method unknown  addSelectionAndWait()
      * @method unknown  allowNativeXpath()
+     * @method unknown  allowNativeXpathAndWait()
      * @method unknown  altKeyDown()
      * @method unknown  altKeyDownAndWait()
      * @method unknown  altKeyUp()
      * @method unknown  altKeyUpAndWait()
      * @method unknown  answerOnNextPrompt()
      * @method unknown  assignId()
+     * @method unknown  assignIdAndWait()
+     * @method unknown  attachFile()
      * @method unknown  break()
      * @method unknown  captureEntirePageScreenshot()
-     * @method unknown  captureScreenshot()
+     * @method unknown  captureEntirePageScreenshotAndWait()
+     * @method unknown  captureEntirePageScreenshotToStringAndWait()
+     * @method unknown  captureScreenshotAndWait()
+     * @method unknown  captureScreenshotToStringAndWait()
      * @method unknown  check()
+     * @method unknown  checkAndWait()
      * @method unknown  chooseCancelOnNextConfirmation()
+     * @method unknown  chooseCancelOnNextConfirmationAndWait()
      * @method unknown  chooseOkOnNextConfirmation()
+     * @method unknown  chooseOkOnNextConfirmationAndWait()
      * @method unknown  click()
      * @method unknown  clickAndWait()
      * @method unknown  clickAt()
@@ -356,6 +408,8 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
      * @method unknown  deleteAllVisibleCookiesAndWait()
      * @method unknown  deleteCookie()
      * @method unknown  deleteCookieAndWait()
+     * @method unknown  deselectPopUp()
+     * @method unknown  deselectPopUpAndWait()
      * @method unknown  doubleClick()
      * @method unknown  doubleClickAndWait()
      * @method unknown  doubleClickAt()
@@ -370,6 +424,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
      * @method unknown  fireEvent()
      * @method unknown  fireEventAndWait()
      * @method unknown  focus()
+     * @method unknown  focusAndWait()
      * @method string   getAlert()
      * @method array    getAllButtons()
      * @method array    getAllFields()
@@ -382,6 +437,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
      * @method string   getBodyText()
      * @method string   getConfirmation()
      * @method string   getCookie()
+     * @method string   getCookieByName()
      * @method integer  getCursorPosition()
      * @method integer  getElementHeight()
      * @method integer  getElementIndex()
@@ -418,9 +474,11 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
      * @method unknown  highlight()
      * @method unknown  highlightAndWait()
      * @method unknown  ignoreAttributesWithoutValue()
+     * @method unknown  ignoreAttributesWithoutValueAndWait()
      * @method boolean  isAlertPresent()
      * @method boolean  isChecked()
      * @method boolean  isConfirmationPresent()
+     * @method boolean  isCookiePresent()
      * @method boolean  isEditable()
      * @method boolean  isElementPresent()
      * @method boolean  isOrdered()
@@ -430,10 +488,16 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
      * @method boolean  isVisible()
      * @method unknown  keyDown()
      * @method unknown  keyDownAndWait()
+     * @method unknown  keyDownNative()
+     * @method unknown  keyDownNativeAndWait()
      * @method unknown  keyPress()
      * @method unknown  keyPressAndWait()
+     * @method unknown  keyPressNative()
+     * @method unknown  keyPressNativeAndWait()
      * @method unknown  keyUp()
      * @method unknown  keyUpAndWait()
+     * @method unknown  keyUpNative()
+     * @method unknown  keyUpNativeAndWait()
      * @method unknown  metaKeyDown()
      * @method unknown  metaKeyDownAndWait()
      * @method unknown  metaKeyUp()
@@ -466,14 +530,23 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
      * @method unknown  refreshAndWait()
      * @method unknown  removeAllSelections()
      * @method unknown  removeAllSelectionsAndWait()
+     * @method unknown  removeScript()
+     * @method unknown  removeScriptAndWait()
      * @method unknown  removeSelection()
      * @method unknown  removeSelectionAndWait()
+     * @method unknown  retrieveLastRemoteControlLogs()
+     * @method unknown  rollup()
+     * @method unknown  rollupAndWait()
      * @method unknown  runScript()
+     * @method unknown  runScriptAndWait()
      * @method unknown  select()
      * @method unknown  selectAndWait()
      * @method unknown  selectFrame()
+     * @method unknown  selectPopUp()
+     * @method unknown  selectPopUpAndWait()
      * @method unknown  selectWindow()
      * @method unknown  setBrowserLogLevel()
+     * @method unknown  setBrowserLogLevelAndWait()
      * @method unknown  setContext()
      * @method unknown  setCursorPosition()
      * @method unknown  setCursorPositionAndWait()
@@ -485,60 +558,8 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
      * @method unknown  shiftKeyDownAndWait()
      * @method unknown  shiftKeyUp()
      * @method unknown  shiftKeyUpAndWait()
+     * @method unknown  shutDownSeleniumServer()
      * @method unknown  store()
-     * @method unknown  storeAlert()
-     * @method unknown  storeAlertPresent()
-     * @method unknown  storeAllButtons()
-     * @method unknown  storeAllFields()
-     * @method unknown  storeAllLinks()
-     * @method unknown  storeAllWindowIds()
-     * @method unknown  storeAllWindowNames()
-     * @method unknown  storeAllWindowTitle()s
-     * @method unknown  storeAttribute()
-     * @method unknown  storeAttributeFromAllWindows()
-     * @method unknown  storeBodyText()
-     * @method unknown  storeChecked()
-     * @method unknown  storeConfirmation()
-     * @method unknown  storeConfirmationPresent()
-     * @method unknown  storeCookie()
-     * @method unknown  storeCookieByName()
-     * @method unknown  storeCookiePresent()
-     * @method unknown  storeCursorPosition()
-     * @method unknown  storeEditable()
-     * @method unknown  storeElementHeight()
-     * @method unknown  storeElementIndex()
-     * @method unknown  storeElementPositionLeft()
-     * @method unknown  storeElementPositionTop()
-     * @method unknown  storeElementPresent()
-     * @method unknown  storeElementWidth()
-     * @method unknown  storeEval()
-     * @method unknown  storeExpression()
-     * @method unknown  storeHtmlSource()
-     * @method unknown  storeLocation()
-     * @method unknown  storeMouseSpeed()
-     * @method unknown  storeOrdered()
-     * @method unknown  storePrompt()
-     * @method unknown  storePromptPresent()
-     * @method unknown  storeSelectOptions()
-     * @method unknown  storeSelectedId()
-     * @method unknown  storeSelectedIds()
-     * @method unknown  storeSelectedIndex()
-     * @method unknown  storeSelectedIndexes()
-     * @method unknown  storeSelectedLabel()
-     * @method unknown  storeSelectedLabels()
-     * @method unknown  storeSelectedValue()
-     * @method unknown  storeSelectedValues()
-     * @method unknown  storeSomethingSelected()
-     * @method unknown  storeSpeed()
-     * @method unknown  storeTable()
-     * @method unknown  storeText()
-     * @method unknown  storeTextPresent()
-     * @method unknown  storeTitle()
-     * @method unknown  storeValue()
-     * @method unknown  storeVisible()
-     * @method unknown  storeWhetherThisFrameMatchFrameExpression()
-     * @method unknown  storeWhetherThisWindowMatchWindowExpression()
-     * @method unknown  storeXpathCount()
      * @method unknown  submit()
      * @method unknown  submitAndWait()
      * @method unknown  type()
@@ -547,6 +568,8 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
      * @method unknown  typeKeysAndWait()
      * @method unknown  uncheck()
      * @method unknown  uncheckAndWait()
+     * @method unknown  useXpathLibrary()
+     * @method unknown  useXpathLibraryAndWait()
      * @method unknown  waitForCondition()
      * @method unknown  waitForPageToLoad()
      * @method unknown  waitForPopUp()
@@ -564,15 +587,19 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
 
         switch ($command) {
             case 'addLocationStrategy':
+            case 'addScript':
             case 'addSelection':
             case 'allowNativeXpath':
             case 'altKeyDown':
             case 'altKeyUp':
             case 'answerOnNextPrompt':
             case 'assignId':
+            case 'attachFile':
             case 'break':
             case 'captureEntirePageScreenshot':
+            case 'captureEntirePageScreenshotToString':
             case 'captureScreenshot':
+            case 'captureScreenshotToString':
             case 'check':
             case 'chooseCancelOnNextConfirmation':
             case 'chooseOkOnNextConfirmation':
@@ -586,6 +613,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
             case 'createCookie':
             case 'deleteAllVisibleCookies':
             case 'deleteCookie':
+            case 'deselectPopUp':
             case 'doubleClick':
             case 'doubleClickAt':
             case 'dragAndDrop':
@@ -598,8 +626,11 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
             case 'highlight':
             case 'ignoreAttributesWithoutValue':
             case 'keyDown':
+            case 'keyDownNative':
             case 'keyPress':
+            case 'keyPressNative':
             case 'keyUp':
+            case 'keyUpNative':
             case 'metaKeyDown':
             case 'metaKeyUp':
             case 'mouseDown':
@@ -617,10 +648,14 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
             case 'pause':
             case 'refresh':
             case 'removeAllSelections':
+            case 'removeScript':
             case 'removeSelection':
+            case 'retrieveLastRemoteControlLogs':
+            case 'rollup':
             case 'runScript':
             case 'select':
             case 'selectFrame':
+            case 'selectPopUp':
             case 'selectWindow':
             case 'setBrowserLogLevel':
             case 'setContext':
@@ -629,66 +664,16 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
             case 'setSpeed':
             case 'shiftKeyDown':
             case 'shiftKeyUp':
+            case 'shutDownSeleniumServer':
             case 'store':
-            case 'storeAlert':
-            case 'storeAlertPresent':
-            case 'storeAllButtons':
-            case 'storeAllFields':
-            case 'storeAllLinks':
-            case 'storeAllWindowIds':
-            case 'storeAllWindowNames':
-            case 'storeAllWindowTitles':
-            case 'storeAttribute':
-            case 'storeAttributeFromAllWindows':
-            case 'storeBodyText':
-            case 'storeChecked':
-            case 'storeConfirmation':
-            case 'storeConfirmationPresent':
-            case 'storeCookie':
-            case 'storeCookieByName':
-            case 'storeCookiePresent':
-            case 'storeCursorPosition':
-            case 'storeEditable':
-            case 'storeElementHeight':
-            case 'storeElementIndex':
-            case 'storeElementPositionLeft':
-            case 'storeElementPositionTop':
-            case 'storeElementPresent':
-            case 'storeElementWidth':
-            case 'storeEval':
-            case 'storeExpression':
-            case 'storeHtmlSource':
-            case 'storeLocation':
-            case 'storeMouseSpeed':
-            case 'storeOrdered':
-            case 'storePrompt':
-            case 'storePromptPresent':
-            case 'storeSelectOptions':
-            case 'storeSelectedId':
-            case 'storeSelectedIds':
-            case 'storeSelectedIndex':
-            case 'storeSelectedIndexes':
-            case 'storeSelectedLabel':
-            case 'storeSelectedLabels':
-            case 'storeSelectedValue':
-            case 'storeSelectedValues':
-            case 'storeSomethingSelected':
-            case 'storeSpeed':
-            case 'storeTable':
-            case 'storeText':
-            case 'storeTextPresent':
-            case 'storeTitle':
-            case 'storeValue':
-            case 'storeVisible':
-            case 'storeWhetherThisFrameMatchFrameExpression':
-            case 'storeWhetherThisWindowMatchWindowExpression':
-            case 'storeXpathCount':
             case 'submit':
             case 'type':
             case 'typeKeys':
             case 'uncheck':
+            case 'useXpathLibrary':
             case 'windowFocus':
-            case 'windowMaximize': {
+            case 'windowMaximize':
+            case isset(self::$autoGeneratedCommands[$command]): {
                 // Pre-Command Actions
                 switch ($command) {
                     case 'open':
@@ -703,16 +688,28 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
                         }
                     }
                     break;
+                    case 'store':
+                        // store is a synonym of storeExpression
+                        // and RC only understands storeExpression
+                        $command = 'storeExpression';
+                    break;
                 }
 
-                $this->doCommand($command, $arguments);
+                if (isset(self::$autoGeneratedCommands[$command]) && self::$autoGeneratedCommands[$command]['functionHelper']) {
+                    $helperArguments = array($command, $arguments, self::$autoGeneratedCommands[$command]);
+                    call_user_func_array(array($this, self::$autoGeneratedCommands[$command]['functionHelper']), $helperArguments);
+                } else {
+                    $this->doCommand($command, $arguments);
+                }
 
                 // Post-Command Actions
                 switch ($command) {
                     case 'addLocationStrategy':
                     case 'allowNativeXpath':
                     case 'assignId':
-                    case 'captureScreenshot': {
+                    case 'captureEntirePageScreenshot':
+                    case 'captureScreenshot':
+                    case 'captureScreenshotToString': {
                         // intentionally empty
                     }
                     break;
@@ -720,7 +717,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
                     default: {
                         if ($wait) {
                             if ($this->useWaitForPageToLoad) {
-                                $this->waitForPageToLoad($this->timeout);
+                                $this->waitForPageToLoad($this->seleniumTimeout * 1000);
                             } else {
                                 sleep($this->wait);
                             }
@@ -741,6 +738,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
             case 'isAlertPresent':
             case 'isChecked':
             case 'isConfirmationPresent':
+            case 'isCookiePresent':
             case 'isEditable':
             case 'isElementPresent':
             case 'isOrdered':
@@ -764,7 +762,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
                 $result = $this->getNumber($command, $arguments);
 
                 if ($wait) {
-                    $this->waitForPageToLoad($this->timeout);
+                    $this->waitForPageToLoad($this->seleniumTimeout * 1000);
                 }
 
                 return $result;
@@ -776,6 +774,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
             case 'getBodyText':
             case 'getConfirmation':
             case 'getCookie':
+            case 'getCookieByName':
             case 'getEval':
             case 'getExpression':
             case 'getHtmlSource':
@@ -793,7 +792,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
                 $result = $this->getString($command, $arguments);
 
                 if ($wait) {
-                    $this->waitForPageToLoad($this->timeout);
+                    $this->waitForPageToLoad($this->seleniumTimeout * 1000);
                 }
 
                 return $result;
@@ -815,7 +814,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
                 $result = $this->getStringArray($command, $arguments);
 
                 if ($wait) {
-                    $this->waitForPageToLoad($this->timeout);
+                    $this->waitForPageToLoad($this->seleniumTimeout * 1000);
                 }
 
                 return $result;
@@ -826,7 +825,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
             case 'waitForFrameToLoad':
             case 'waitForPopUp': {
                 if (count($arguments) == 1) {
-                    $arguments[] = $this->timeout;
+                    $arguments[] = $this->seleniumTimeout * 1000;
                 }
 
                 $this->doCommand($command, $arguments);
@@ -836,7 +835,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
 
             case 'waitForPageToLoad': {
                 if (empty($arguments)) {
-                    $arguments[] = $this->timeout;
+                    $arguments[] = $this->seleniumTimeout * 1000;
                 }
 
                 $this->doCommand($command, $arguments);
@@ -866,7 +865,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
     protected function doCommand($command, array $arguments = array())
     {
         if (!ini_get('allow_url_fopen')) {
-            throw new RuntimeException(
+            throw new PHPUnit_Framework_Exception(
               'Could not connect to the Selenium RC server because allow_url_fopen is disabled.'
             );
         }
@@ -889,16 +888,26 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
             $url .= sprintf('&%s=%s', 'sessionId', $this->sessionId);
         }
 
-        $handle = @fopen($url, 'r');
+        $this->commands[] = sprintf('%s(%s)', $command, join(', ', $arguments));
+
+        $context = stream_context_create(
+          array(
+            'http' => array(
+              'timeout' => $this->httpTimeout
+            )
+          )
+        );
+
+        $handle = @fopen($url, 'r', FALSE, $context);
 
         if (!$handle) {
-            throw new RuntimeException(
+            throw new PHPUnit_Framework_Exception(
               'Could not connect to the Selenium RC server.'
             );
         }
 
         stream_set_blocking($handle, 1);
-        stream_set_timeout($handle, 0, $this->timeout);
+        stream_set_timeout($handle, 0, $this->httpTimeout * 1000);
 
         $info     = stream_get_meta_data($handle);
         $response = '';
@@ -913,8 +922,12 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
         if (!preg_match('/^OK/', $response)) {
             $this->stop();
 
-            throw new RuntimeException(
-              'The response from the Selenium RC server is invalid: ' . $response
+            throw new PHPUnit_Framework_Exception(
+              sprintf(
+                "Response from Selenium RC server for %s.\n%s.\n",
+                $this->commands[count($this->commands)-1],
+                $response
+              )
             );
         }
 
@@ -943,7 +956,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
             default: {
                 $this->stop();
 
-                throw new RuntimeException(
+                throw new PHPUnit_Framework_Exception(
                   'Result is neither "true" nor "false": ' . PHPUnit_Util_Type::toString($result, TRUE)
                 );
             }
@@ -967,7 +980,7 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
         if (!is_numeric($result)) {
             $this->stop();
 
-            throw new RuntimeException(
+            throw new PHPUnit_Framework_Exception(
               'Result is not numeric: ' . PHPUnit_Util_Type::toString($result, TRUE)
             );
         }
@@ -1044,5 +1057,164 @@ class PHPUnit_Extensions_SeleniumTestCase_Driver
 
         return $tokens;
     }
+
+    public function getVerificationErrors()
+    {
+        return $this->verificationErrors;
+    }
+
+    public function clearVerificationErrors()
+    {
+        $this->verificationErrors = array();
+    }
+
+    protected function assertCommand($command, $arguments, $info)
+    {
+        $method = $info['originalMethod'];
+        $result = $this->__call($method, $arguments);
+
+        if ($info['isBoolean']) {
+            if (!isset($info['negative']) || !$info['negative']) {
+                PHPUnit_Framework_Assert::assertTrue($result);
+            } else {
+                PHPUnit_Framework_Assert::assertFalse($result);
+            }
+        } else {
+            $expected = array_pop($arguments);
+
+            if (strpos($expected, 'exact:') === 0) {
+                $expected = substr($expected, strlen('exact:'));
+
+                if (!isset($info['negative']) || !$info['negative']) {
+                    PHPUnit_Framework_Assert::assertEquals($expected, $result);
+                } else {
+                    PHPUnit_Framework_Assert::assertNotEquals($expected, $result);
+                }
+            } else {
+                if (strpos($expected, 'regexp:') === 0) {
+                    $expected = substr($expected, strlen('regexp:'));
+                } else {
+                    if (strpos($expected, 'glob:') === 0) {
+                        $expected = substr($expected, strlen('glob:'));
+                    }
+
+                    $expected = str_replace(
+                      array('*', '?'), array('.*', '.?'), $expected
+                    );
+                }
+
+                $expected = str_replace('/', '\/', $expected);
+
+                if (!isset($info['negative']) || !$info['negative']) {
+                    PHPUnit_Framework_Assert::assertRegExp(
+                      '/' . $expected . '/', $result
+                    );
+                } else {
+                    PHPUnit_Framework_Assert::assertNotRegExp(
+                      '/' . $expected . '/', $result
+                    );
+                }
+            }
+        }
+    }
+
+    protected function verifyCommand($command, $arguments, $info)
+    {
+        try {
+            $this->assertCommand($command, $arguments, $info);
+        }
+
+        catch (PHPUnit_Framework_AssertionFailedError $e) {
+            array_push($this->verificationErrors, $e->toString());
+        }
+    }
+
+    protected function waitForCommand($command, $arguments, $info)
+    {
+        for ($second = 0; ; $second++) {
+            if ($second > $this->httpTimeout) {
+                PHPUnit_Framework_Assert::fail('timeout');
+            }
+
+            try {
+                $this->assertCommand($command, $arguments, $info);
+                return;
+            }
+
+            catch (Exception $e) {
+            }
+
+            sleep(1);
+        }
+    }
+
+    /**
+     * Parses the docblock of PHPUnit_Extensions_SeleniumTestCase_Driver::__call
+     * for get*(), is*(), assert*(), verify*(), assertNot*(), verifyNot*(),
+     * store*(), waitFor*(), and waitForNot*() methods.
+     */
+    protected static function autoGenerateCommands()
+    {
+        $method     = new ReflectionMethod(__CLASS__, '__call');
+        $docComment = $method->getDocComment();
+
+        if (preg_match_all('(@method\s+(\w+)\s+([\w]+)\(\))', $docComment, $matches)) {
+            foreach ($matches[2] as $method) {
+                if (preg_match('/^(get|is)([A-Z].+)$/', $method, $matches)) {
+                    $baseName  = $matches[2];
+                    $isBoolean = $matches[1] == 'is';
+
+                    if (preg_match('/^(.*)Present$/', $baseName, $matches)) {
+                        $notBaseName = $matches[1].'NotPresent';
+                    } else {
+                        $notBaseName = 'Not'.$baseName;
+                    }
+
+                    self::$autoGeneratedCommands['store' . $baseName] = array(
+                      'functionHelper' => FALSE
+                    );
+
+                    self::$autoGeneratedCommands['assert' . $baseName] = array(
+                      'originalMethod' => $method,
+                      'isBoolean'      => $isBoolean,
+                      'functionHelper' => 'assertCommand'
+                    );
+
+                    self::$autoGeneratedCommands['assert' . $notBaseName] = array(
+                      'originalMethod' => $method,
+                      'isBoolean'      => $isBoolean,
+                      'negative'       => TRUE,
+                      'functionHelper' => 'assertCommand'
+                    );
+
+                    self::$autoGeneratedCommands['verify' . $baseName] = array(
+                      'originalMethod' => $method,
+                      'isBoolean'      => $isBoolean,
+                      'functionHelper' => 'verifyCommand'
+                    );
+
+                    self::$autoGeneratedCommands['verify' . $notBaseName] = array(
+                      'originalMethod' => $method,
+                      'isBoolean'      => $isBoolean,
+                      'negative'       => TRUE,
+                      'functionHelper' => 'verifyCommand'
+                    );
+
+                    self::$autoGeneratedCommands['waitFor' . $baseName] = array(
+                      'originalMethod' => $method,
+                      'isBoolean'      => $isBoolean,
+                      'functionHelper' => 'waitForCommand'
+                    );
+
+                    self::$autoGeneratedCommands['waitFor' . $notBaseName] = array(
+                      'originalMethod' => $method,
+                      'isBoolean'      => $isBoolean,
+                      'negative'       => TRUE,
+                      'functionHelper' => 'waitForCommand'
+                    );
+                }
+            }
+        }
+    }
 }
 ?>
