@@ -36,33 +36,28 @@
  *
  * @category   Testing
  * @package    PHPUnit
- * @author     Jan Borsodi <jb@ez.no>
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: ComparisonFailure.php 4748 2009-04-02 06:34:34Z sb $
+ * @version    SVN: $Id: ComparisonFailure.php 5164 2009-08-29 10:38:39Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 2.0.0
  */
 
 require_once 'PHPUnit/Framework.php';
-require_once 'PHPUnit/Util/Filter.php';
 require_once 'PHPUnit/Util/Type.php';
 
 PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
 
-if (!class_exists('PHPUnit_Framework_ComparisonFailure', FALSE)) {
-
 /**
  * Thrown when an assertion for string equality failed.
  *
  * @category   Testing
  * @package    PHPUnit
- * @author     Jan Borsodi <jb@ez.no>
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.3.16
+ * @version    Release: 3.4.5
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 2.0.0
  */
@@ -92,11 +87,6 @@ abstract class PHPUnit_Framework_ComparisonFailure extends PHPUnit_Framework_Ass
      */
     protected $message;
 
-    /**
-     * @var boolean
-     */
-    protected static $hasDiff = NULL;
-
     /**
      * Initialises with the expected value and the actual value.
      *
@@ -104,7 +94,7 @@ abstract class PHPUnit_Framework_ComparisonFailure extends PHPUnit_Framework_Ass
      * @param mixed $actual Actual value retrieved.
      * @param boolean $identical
      * @param string $message A string which is prefixed on all returned lines
-     *                       in the difference output.
+     *                        in the difference output.
      */
     public function __construct($expected, $actual, $identical = FALSE, $message = '')
     {
@@ -114,16 +104,25 @@ abstract class PHPUnit_Framework_ComparisonFailure extends PHPUnit_Framework_Ass
         $this->message   = $message;
     }
 
+    /**
+     * @return mixed
+     */
     public function getActual()
     {
         return $this->actual;
     }
 
+    /**
+     * @return mixed
+     */
     public function getExpected()
     {
         return $this->expected;
     }
 
+    /**
+     * @return boolean
+     */
     public function identical()
     {
         return $this->identical;
@@ -138,29 +137,39 @@ abstract class PHPUnit_Framework_ComparisonFailure extends PHPUnit_Framework_Ass
      * @param mixed $expected Expected value retrieved.
      * @param mixed $actual Actual value retrieved.
      * @param string $message A string which is prefixed on all returned lines
-     *                       in the difference output.
+     *                        in the difference output.
      * @return PHPUnit_Framework_ComparisonFailure
      */
     public static function diffIdentical($expected, $actual, $message = '')
     {
         if (gettype($expected) !== gettype($actual)) {
-            return new PHPUnit_Framework_ComparisonFailure_Type($expected, $actual, TRUE, $message);
+            return new PHPUnit_Framework_ComparisonFailure_Type(
+              $expected, $actual, TRUE, $message
+            );
         }
 
-        elseif (is_string($expected)) {
-            return new PHPUnit_Framework_ComparisonFailure_String($expected, $actual, TRUE, $message);
+        else if (is_array($expected) && is_array($actual)) {
+            return new PHPUnit_Framework_ComparisonFailure_Array(
+              $expected, $actual, TRUE, $message
+            );
         }
 
-        elseif (is_null($expected) || is_scalar($expected)) {
-            return new PHPUnit_Framework_ComparisonFailure_Scalar($expected, $actual, TRUE, $message);
+        else if (is_object($expected) && is_object($actual)) {
+            return new PHPUnit_Framework_ComparisonFailure_Object(
+              $expected, $actual, TRUE, $message
+            );
         }
 
-        elseif (is_array($expected)) {
-            return new PHPUnit_Framework_ComparisonFailure_Array($expected, $actual, TRUE, $message);
+        else if (is_string($expected) && !is_object($actual)) {
+            return new PHPUnit_Framework_ComparisonFailure_String(
+              $expected, $actual, TRUE, $message
+            );
         }
 
-        elseif (is_object($expected)) {
-            return new PHPUnit_Framework_ComparisonFailure_Object($expected, $actual, TRUE, $message);
+        else if (is_null($expected) || is_scalar($expected)) {
+            return new PHPUnit_Framework_ComparisonFailure_Scalar(
+              $expected, $actual, TRUE, $message
+            );
         }
     }
 
@@ -173,120 +182,35 @@ abstract class PHPUnit_Framework_ComparisonFailure extends PHPUnit_Framework_Ass
      * @param mixed $expected Expected value retrieved.
      * @param mixed $actual Actual value retrieved.
      * @param string $message A string which is prefixed on all returned lines
-     *                       in the difference output.
+     *                        in the difference output.
      * @return PHPUnit_Framework_ComparisonFailure
      */
     public static function diffEqual($expected, $actual, $message = '')
     {
-        if (is_string($expected) && !is_object($actual)) {
-            return new PHPUnit_Framework_ComparisonFailure_String($expected, $actual, FALSE, $message);
+        if (is_array($expected) && is_array($actual)) {
+            return new PHPUnit_Framework_ComparisonFailure_Array(
+              $expected, $actual, FALSE, $message
+            );
         }
 
-        elseif (is_null($expected) || is_scalar($expected)) {
-            return new PHPUnit_Framework_ComparisonFailure_Scalar($expected, $actual, FALSE, $message);
+        else if (is_object($expected) && is_object($actual)) {
+            return new PHPUnit_Framework_ComparisonFailure_Object(
+              $expected, $actual, FALSE, $message
+            );
         }
 
-        elseif (is_array($expected)) {
-            return new PHPUnit_Framework_ComparisonFailure_Array($expected, $actual, FALSE, $message);
+        else if (is_string($expected) && !is_object($actual)) {
+            return new PHPUnit_Framework_ComparisonFailure_String(
+              $expected, $actual, FALSE, $message
+            );
         }
 
-        elseif (is_object($expected)) {
-            return new PHPUnit_Framework_ComparisonFailure_Object($expected, $actual, FALSE, $message);
+        else if (is_null($expected) || is_scalar($expected)) {
+            return new PHPUnit_Framework_ComparisonFailure_Scalar(
+              $expected, $actual, FALSE, $message
+            );
         }
     }
-
-    protected function diff($expected, $actual)
-    {
-        if (defined('PHPUNIT_TMPDIR')) {
-            $tmpDir = PHPUNIT_TMPDIR;
-        }
-
-        else if (function_exists('sys_get_temp_dir')) {
-            $tmpDir = sys_get_temp_dir();
-        }
-
-        else {
-            $tmpDir = '/tmp';
-        }
-
-        $expectedFile = tempnam($tmpDir, 'expected');
-        $actualFile   = tempnam($tmpDir, 'actual');
-
-        file_put_contents($expectedFile, $expected);
-        file_put_contents($actualFile, $actual);
-
-        $buffer = shell_exec(
-          sprintf(
-            'diff -u %s %s',
-            escapeshellarg($expectedFile),
-            escapeshellarg($actualFile)
-          )
-        );
-
-        unlink($expectedFile);
-        unlink($actualFile);
-
-        if (!empty($buffer)) {
-            $buffer = explode("\n", $buffer);
-
-            $buffer[0] = "--- Expected";
-            $buffer[1] = "+++ Actual";
-
-            $buffer = implode("\n", $buffer);
-        }
-
-        return $buffer;
-    }
-
-    public static function hasDiff()
-    {
-        if (self::$hasDiff === NULL)
-        {
-            self::$hasDiff = FALSE;
-
-            $binary = 'diff';
-
-            if (substr(php_uname('s'), 0, 7) == 'Windows')
-            {
-                $binary .= '.exe';
-            }
-
-            if (isset($_ENV['PATH'])) {
-                $var = $_ENV['PATH'];
-            }
-
-            else if (isset($_ENV['Path'])) {
-                $var = $_ENV['Path'];
-            }
-
-            else if (isset($_SERVER['PATH'])) {
-                $var = $_SERVER['PATH'];
-            }
-
-            else if (isset($_SERVER['Path'])) {
-                $var = $_SERVER['Path'];
-            }
-
-            if (isset($var)) {
-                $paths = explode(PATH_SEPARATOR, $var);
-            } else {
-                $paths = array();
-            }
-
-            foreach ($paths as $path) {
-                if (file_exists($path . DIRECTORY_SEPARATOR . $binary) &&
-                    is_executable($path . DIRECTORY_SEPARATOR . $binary))
-                {
-                    self::$hasDiff = TRUE;
-                    break;
-                }
-            }
-        }
-
-        return self::$hasDiff;
-    }
-}
-
 }
 
 require_once 'PHPUnit/Framework/ComparisonFailure/Array.php';
