@@ -36,49 +36,47 @@
  *
  * @category   Testing
  * @package    PHPUnit
- * @author     Jan Borsodi <jb@ez.no>
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: Constraint.php 4404 2008-12-31 09:27:18Z sb $
+ * @version    SVN: $Id: Constraint.php 5164 2009-08-29 10:38:39Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 3.0.0
  */
 
 require_once 'PHPUnit/Framework.php';
-require_once 'PHPUnit/Util/Filter.php';
 
 PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
 
-if (!class_exists('PHPUnit_Framework_Constraint', FALSE)) {
-
 /**
  * Abstract base class for constraints. which are placed upon any value.
  *
  * @category   Testing
  * @package    PHPUnit
- * @author     Jan Borsodi <jb@ez.no>
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.3.16
+ * @version    Release: 3.4.5
  * @link       http://www.phpunit.de/
  * @since      Interface available since Release 3.0.0
  */
-abstract class PHPUnit_Framework_Constraint implements PHPUnit_Framework_SelfDescribing
+abstract class PHPUnit_Framework_Constraint implements Countable, PHPUnit_Framework_SelfDescribing
 {
     /**
-     * Evaluates the constraint for parameter $other. Returns TRUE if the
-     * constraint is met, FALSE otherwise.
+     * Counts the number of constraint elements.
      *
-     * @param mixed $other Value or object to evaluate.
-     * @return bool
+     * @return integer
+     * @since  Method available since Release 3.4.0
      */
-    abstract public function evaluate($other);
+    public function count()
+    {
+        return 1;
+    }
 
     /**
      * Creates the appropriate exception for the constraint which can be caught
-     * by the unit test system. This can be called if a call to evaluate() fails.
+     * by the unit test system. This can be called if a call to evaluate()
+     * fails.
      *
      * @param   mixed   $other The value passed to evaluate() which failed the
      *                         constraint check.
@@ -95,6 +93,11 @@ abstract class PHPUnit_Framework_Constraint implements PHPUnit_Framework_SelfDes
         );
     }
 
+    /**
+     * @param mixed   $other
+     * @param string  $description
+     * @param boolean $not
+     */
     protected function failureDescription($other, $description, $not)
     {
         $failureDescription = $this->customFailureDescription(
@@ -121,10 +124,19 @@ abstract class PHPUnit_Framework_Constraint implements PHPUnit_Framework_SelfDes
         return $failureDescription;
     }
 
+    /**
+     * @param mixed   $other
+     * @param string  $description
+     * @param boolean $not
+     */
     protected function customFailureDescription($other, $description, $not)
     {
     }
 
+    /**
+     * @param  string $string
+     * @return string
+     */
     public static function negate($string)
     {
         return str_replace(
@@ -133,20 +145,31 @@ abstract class PHPUnit_Framework_Constraint implements PHPUnit_Framework_SelfDes
             'exists',
             'has ',
             'is ',
-            'matches '
+            'matches ',
+            'starts with ',
+            'ends with '
           ),
           array(
             'does not contain ',
             'does not exist',
             'does not have ',
             'is not ',
-            'does not match '
+            'does not match ',
+            'starts not with ',
+            'ends not with '
           ),
           $string
         );
     }
-}
 
+    /**
+     * Evaluates the constraint for parameter $other. Returns TRUE if the
+     * constraint is met, FALSE otherwise.
+     *
+     * @param mixed $other Value or object to evaluate.
+     * @return bool
+     */
+    abstract public function evaluate($other);
 }
 
 require_once 'PHPUnit/Framework/Constraint/And.php';
@@ -169,6 +192,8 @@ require_once 'PHPUnit/Framework/Constraint/ObjectHasAttribute.php';
 require_once 'PHPUnit/Framework/Constraint/Or.php';
 require_once 'PHPUnit/Framework/Constraint/PCREMatch.php';
 require_once 'PHPUnit/Framework/Constraint/StringContains.php';
+require_once 'PHPUnit/Framework/Constraint/StringStartsWith.php';
+require_once 'PHPUnit/Framework/Constraint/StringEndsWith.php';
 require_once 'PHPUnit/Framework/Constraint/TraversableContains.php';
 require_once 'PHPUnit/Framework/Constraint/TraversableContainsOnly.php';
 require_once 'PHPUnit/Framework/Constraint/IsTrue.php';
