@@ -36,11 +36,10 @@
  *
  * @category   Testing
  * @package    PHPUnit
- * @author     Jan Borsodi <jb@ez.no>
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: IsType.php 4404 2008-12-31 09:27:18Z sb $
+ * @version    SVN: $Id: IsType.php 5436 2009-12-12 12:19:40Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 3.0.0
  */
@@ -58,11 +57,10 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
  *
  * @category   Testing
  * @package    PHPUnit
- * @author     Jan Borsodi <jb@ez.no>
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.3.16
+ * @version    Release: 3.4.5
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 3.0.0
  */
@@ -77,35 +75,45 @@ class PHPUnit_Framework_Constraint_IsType extends PHPUnit_Framework_Constraint
     const TYPE_OBJECT   = 'object';
     const TYPE_RESOURCE = 'resource';
     const TYPE_STRING   = 'string';
+    const TYPE_SCALAR   = 'scalar';
 
+    /**
+     * @var array
+     */
+    protected $types = array(
+      'array' => TRUE,
+      'boolean' => TRUE,
+      'bool' => TRUE,
+      'float' => TRUE,
+      'integer' => TRUE,
+      'int' => TRUE,
+      'null' => TRUE,
+      'numeric' => TRUE,
+      'object' => TRUE,
+      'resource' => TRUE,
+      'string' => TRUE,
+      'scalar' => TRUE
+    );
+
+    /**
+     * @var string
+     */
     protected $type;
 
+    /**
+     * @param  string $type
+     * @throws InvalidArgumentException
+     */
     public function __construct($type)
     {
-        switch ($type) {
-            case 'array':
-            case 'boolean':
-            case 'bool':
-            case 'float':
-            case 'integer':
-            case 'int':
-            case 'null':
-            case 'numeric':
-            case 'object':
-            case 'resource':
-            case 'string': {
-              break;
-            }
-
-            default: {
-              throw new InvalidArgumentException(
-                sprintf(
-                  'Type specified for PHPUnit_Framework_Constraint_IsType <%s> is not a valid type.',
-
-                  $type
-                )
-              );
-            }
+        if (!isset($this->types[$type])) {
+            throw new InvalidArgumentException(
+              sprintf(
+                'Type specified for PHPUnit_Framework_Constraint_IsType <%s> ' .
+                'is not a valid type.',
+                $type
+              )
+            );
         }
 
         $this->type = $type;
@@ -122,41 +130,45 @@ class PHPUnit_Framework_Constraint_IsType extends PHPUnit_Framework_Constraint
     {
         switch ($this->type) {
             case 'numeric': {
-              return is_numeric($other);
+                return is_numeric($other);
             }
 
             case 'integer':
             case 'int': {
-              return is_integer($other);
+                return is_integer($other);
             }
 
             case 'float': {
-              return is_float($other);
+                return is_float($other);
             }
 
             case 'string': {
-              return is_string($other);
+                return is_string($other);
             }
 
             case 'boolean':
             case 'bool': {
-              return is_bool($other);
+                return is_bool($other);
             }
 
             case 'null': {
-              return is_null($other);
+                return is_null($other);
             }
 
             case 'array': {
-              return is_array($other);
+                return is_array($other);
             }
 
             case 'object': {
-              return is_object($other);
+                return is_object($other);
             }
 
             case 'resource': {
-              return is_resource($other);
+                return is_resource($other);
+            }
+
+            case 'scalar': {
+                return is_scalar($other);
             }
         }
     }
