@@ -36,11 +36,10 @@
  *
  * @category   Testing
  * @package    PHPUnit
- * @author     Jan Borsodi <jb@ez.no>
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: Or.php 4404 2008-12-31 09:27:18Z sb $
+ * @version    SVN: $Id: Or.php 5164 2009-08-29 10:38:39Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 3.0.0
  */
@@ -56,25 +55,32 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
  *
  * @category   Testing
  * @package    PHPUnit
- * @author     Jan Borsodi <jb@ez.no>
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.3.16
+ * @version    Release: 3.4.5
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 3.0.0
  */
 class PHPUnit_Framework_Constraint_Or extends PHPUnit_Framework_Constraint
 {
+    /**
+     * @var PHPUnit_Framework_Constraint[]
+     */
     protected $constraints = array();
 
+    /**
+     * @param PHPUnit_Framework_Constraint[] $constraints
+     */
     public function setConstraints(array $constraints)
     {
         $this->constraints = array();
 
         foreach($constraints as $key => $constraint) {
             if (!($constraint instanceof PHPUnit_Framework_Constraint)) {
-                $constraint = new PHPUnit_Framework_Constraint_IsEqual($constraint);
+                $constraint = new PHPUnit_Framework_Constraint_IsEqual(
+                  $constraint
+                );
             }
 
             $this->constraints[] = $constraint;
@@ -99,28 +105,6 @@ class PHPUnit_Framework_Constraint_Or extends PHPUnit_Framework_Constraint
         return FALSE;
     }
 
-    /**
-     * @param   mixed   $other The value passed to evaluate() which failed the
-     *                         constraint check.
-     * @param   string  $description A string with extra description of what was
-     *                               going on while the evaluation failed.
-     * @param   boolean $not Flag to indicate negation.
-     * @throws  PHPUnit_Framework_ExpectationFailedException
-     */
-    public function fail($other, $description, $not = FALSE)
-    {
-        throw new PHPUnit_Framework_ExpectationFailedException(
-          sprintf(
-            'Failed asserting that %s %s.',
-
-             PHPUnit_Util_Type::toString($other),
-             $this->toString()
-          ),
-          NULL,
-          $description
-        );
-    }
-
     /**
      * Returns a string representation of the constraint.
      *
@@ -140,5 +124,22 @@ class PHPUnit_Framework_Constraint_Or extends PHPUnit_Framework_Constraint
 
         return $text;
     }
+
+    /**
+     * Counts the number of constraint elements.
+     *
+     * @return integer
+     * @since  Method available since Release 3.4.0
+     */
+    public function count()
+    {
+        $count = 1;
+
+        foreach ($this->constraints as $constraint) {
+            $count += count($constraint);
+        }
+
+        return $count;
+    }
 }
 ?>
