@@ -39,17 +39,15 @@
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: Notice.php 4404 2008-12-31 09:27:18Z sb $
+ * @version    SVN: $Id: Notice.php 5158 2009-08-29 05:56:57Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 3.3.0
  */
 
-require_once 'PHPUnit/Util/Filter.php';
+require_once 'PHPUnit/Framework.php';
 
 PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
 
-if (!class_exists('PHPUnit_Framework_Error_Notice', FALSE)) {
-
 /**
  * Wrapper for PHP notices.
  * You can disable notice-to-exception conversion by setting
@@ -63,7 +61,7 @@ if (!class_exists('PHPUnit_Framework_Error_Notice', FALSE)) {
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.3.16
+ * @version    Release: 3.4.5
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 3.3.0
  */
@@ -71,6 +69,4 @@ class PHPUnit_Framework_Error_Notice extends PHPUnit_Framework_Error
 {
     public static $enabled = TRUE;
 }
-
-}
 ?>
