@@ -1,7 +1,7 @@
 <?php
 class Success extends PHPUnit_Framework_TestCase
 {
-    public function runTest()
+    protected function runTest()
     {
     }
 }
