@@ -39,7 +39,7 @@
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: ResultPrinter.php 4404 2008-12-31 09:27:18Z sb $
+ * @version    SVN: $Id: ResultPrinter.php 5419 2009-12-09 14:32:17Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 2.0.0
  */
@@ -48,6 +48,7 @@ require_once 'PHPUnit/Framework.php';
 require_once 'PHPUnit/Util/Filter.php';
 require_once 'PHPUnit/Util/Printer.php';
 require_once 'PHPUnit/Util/Test.php';
+require_once 'PHPUnit/Util/Timer.php';
 
 PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
 
@@ -59,7 +60,7 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.3.16
+ * @version    Release: 3.4.5
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 2.0.0
  */
@@ -71,50 +72,60 @@ class PHPUnit_TextUI_ResultPrinter extends PHPUnit_Util_Printer implements PHPUn
     const EVENT_TESTSUITE_END   = 3;
 
     /**
-     * @var    integer
+     * @var integer
      */
     protected $column = 0;
 
     /**
-     * @var    array
+     * @var integer
      */
-    protected $numberOfTests = array();
+    protected $indent = 0;
 
     /**
-     * @var    array
-     */
-    protected $testSuiteSize = array();
-
-    /**
-     * @var    integer
+     * @var integer
      */
     protected $lastEvent = -1;
 
     /**
-     * @var    boolean
+     * @var boolean
      */
     protected $lastTestFailed = FALSE;
 
     /**
-     * @var    boolean
+     * @var integer
+     */
+    protected $numAssertions = 0;
+
+    /**
+     * @var integer
+     */
+    protected $numTests = -1;
+
+    /**
+     * @var integer
+     */
+    protected $numTestsRun = 0;
+
+    /**
+     * @var integer
+     */
+    protected $numTestsWidth;
+
+    /**
+     * @var boolean
      */
     protected $colors = FALSE;
 
     /**
-     * @var    boolean
+     * @var boolean
      */
     protected $debug = FALSE;
 
     /**
-     * @var    boolean
+     * @var boolean
      */
     protected $verbose = FALSE;
 
-    /**
-     * @var    integer
-     */
-    protected $numAssertions = 0;
-
     /**
      * Constructor.
      *
@@ -129,22 +140,22 @@ class PHPUnit_TextUI_ResultPrinter extends PHPUnit_Util_Printer implements PHPUn
     {
         parent::__construct($out);
 
+        if (is_bool($verbose)) {
+            $this->verbose = $verbose;
+        } else {
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(2, 'boolean');
+        }
+
         if (is_bool($colors)) {
             $this->colors = $colors;
         } else {
-            throw new InvalidArgumentException;
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(3, 'boolean');
         }
 
         if (is_bool($debug)) {
             $this->debug = $debug;
         } else {
-            throw new InvalidArgumentException;
-        }
-
-        if (is_bool($verbose)) {
-            $this->verbose = $verbose;
-        } else {
-            throw new InvalidArgumentException;
+            throw PHPUnit_Util_InvalidArgumentHelper::factory(4, 'boolean');
         }
     }
 
@@ -262,7 +273,7 @@ class PHPUnit_TextUI_ResultPrinter extends PHPUnit_Util_Printer implements PHPUn
     protected function printDefectTrace(PHPUnit_Framework_TestFailure $defect)
     {
         $this->write(
-          $defect->toStringVerbose($this->verbose) .
+          $defect->getExceptionAsString() . "\n" .
           PHPUnit_Util_Filter::getFilteredStacktrace(
             $defect->thrownException(),
             FALSE
@@ -283,7 +294,11 @@ class PHPUnit_TextUI_ResultPrinter extends PHPUnit_Util_Printer implements PHPUn
      */
     protected function printFailures(PHPUnit_Framework_TestResult $result)
     {
-        $this->printDefects($result->failures(), $result->failureCount(), 'failure');
+        $this->printDefects(
+          $result->failures(),
+          $result->failureCount(),
+          'failure'
+        );
     }
 
     /**
@@ -291,7 +306,11 @@ class PHPUnit_TextUI_ResultPrinter extends PHPUnit_Util_Printer implements PHPUn
      */
     protected function printIncompletes(PHPUnit_Framework_TestResult $result)
     {
-        $this->printDefects($result->notImplemented(), $result->notImplementedCount(), 'incomplete test');
+        $this->printDefects(
+          $result->notImplemented(),
+          $result->notImplementedCount(),
+          'incomplete test'
+        );
     }
 
     /**
@@ -300,19 +319,43 @@ class PHPUnit_TextUI_ResultPrinter extends PHPUnit_Util_Printer implements PHPUn
      */
     protected function printSkipped(PHPUnit_Framework_TestResult $result)
     {
-        $this->printDefects($result->skipped(), $result->skippedCount(), 'skipped test');
+        $this->printDefects(
+          $result->skipped(),
+          $result->skippedCount(),
+          'skipped test'
+        );
     }
 
     /**
-     * @param  float   $timeElapsed
+     * @param float $timeElapsed
      */
     protected function printHeader($timeElapsed)
     {
+        if (isset($_SERVER['REQUEST_TIME'])) {
+            $timeElapsed = PHPUnit_Util_Timer::secondsToTimeString(
+              time() - $_SERVER['REQUEST_TIME']
+            );
+        } else {
+            $timeElapsed = PHPUnit_Util_Timer::secondsToTimeString(
+              $timeElapsed
+            );
+        }
+
+        if (function_exists('memory_get_peak_usage')) {
+            $memory = sprintf(
+              ', Memory: %4.2fMb',
+              memory_get_peak_usage(TRUE) / 1048576
+            );
+        } else {
+            $memory = '';
+        }
+
         $this->write(
           sprintf(
-            "%sTime: %s\n\n",
+            "%sTime: %s%s\n\n",
             $this->verbose ? "\n" : "\n\n",
-            PHPUnit_Util_Timer::secondsToTimeString($timeElapsed)
+            $timeElapsed,
+            $memory
           )
         );
     }
@@ -349,7 +392,10 @@ class PHPUnit_TextUI_ResultPrinter extends PHPUnit_Util_Printer implements PHPUn
                   !$result->noneSkipped())&&
                  $result->wasSuccessful()) {
             if ($this->colors) {
-                $this->write("\x1b[30;43m\x1b[2KOK, but incomplete or skipped tests!\n\x1b[0m\x1b[30;43m\x1b[2K");
+                $this->write(
+                  "\x1b[30;43m\x1b[2KOK, but incomplete or skipped tests!\n" .
+                  "\x1b[0m\x1b[30;43m\x1b[2K"
+                );
             } else {
                 $this->write("OK, but incomplete or skipped tests!\n");
             }
@@ -360,8 +406,12 @@ class PHPUnit_TextUI_ResultPrinter extends PHPUnit_Util_Printer implements PHPUn
 
                 count($result),
                 $this->numAssertions,
-                $this->getCountString($result->notImplementedCount(), 'Incomplete'),
-                $this->getCountString($result->skippedCount(), 'Skipped')
+                $this->getCountString(
+                  $result->notImplementedCount(), 'Incomplete'
+                ),
+                $this->getCountString(
+                  $result->skippedCount(), 'Skipped'
+                )
               )
             );
 
@@ -374,7 +424,9 @@ class PHPUnit_TextUI_ResultPrinter extends PHPUnit_Util_Printer implements PHPUn
             $this->write("\n");
 
             if ($this->colors) {
-                $this->write("\x1b[37;41m\x1b[2KFAILURES!\n\x1b[0m\x1b[37;41m\x1b[2K");
+                $this->write(
+                  "\x1b[37;41m\x1b[2KFAILURES!\n\x1b[0m\x1b[37;41m\x1b[2K"
+                );
             } else {
                 $this->write("FAILURES!\n");
             }
@@ -387,7 +439,9 @@ class PHPUnit_TextUI_ResultPrinter extends PHPUnit_Util_Printer implements PHPUn
                 $this->numAssertions,
                 $this->getCountString($result->failureCount(), 'Failures'),
                 $this->getCountString($result->errorCount(), 'Errors'),
-                $this->getCountString($result->notImplementedCount(), 'Incomplete'),
+                $this->getCountString(
+                  $result->notImplementedCount(), 'Incomplete'
+                ),
                 $this->getCountString($result->skippedCount(), 'Skipped')
               )
             );
@@ -488,27 +542,36 @@ class PHPUnit_TextUI_ResultPrinter extends PHPUnit_Util_Printer implements PHPUn
      */
     public function startTestSuite(PHPUnit_Framework_TestSuite $suite)
     {
+        if ($this->numTests == -1) {
+            $this->numTests      = count($suite);
+            $this->numTestsWidth = strlen((string)$this->numTests);
+        } else {
+            $this->indent++;
+        }
+
         if ($this->verbose) {
             $name = $suite->getName();
 
             if (empty($name)) {
                 $name = 'Test Suite';
+            } else {
+                $name = preg_replace( '(^.*::(.*?)$)', '\\1', $name );
             }
 
             $this->write(
               sprintf(
-                "%s%s%s\n",
+                "%s%s%s",
 
-                $this->lastEvent == self::EVENT_TESTSUITE_END ? "\n" : '',
-                str_repeat(' ', count($this->testSuiteSize)),
+                $this->lastEvent == self::EVENT_TESTSUITE_END ||
+                $suite instanceof PHPUnit_Framework_TestSuite_DataProvider ?
+                "\n" :
+                '',
+                str_repeat(' ', $this->indent),
                 $name
               )
             );
-        }
 
-        if ($this->verbose || empty($this->numberOfTests)) {
-            array_push($this->numberOfTests, 0);
-            array_push($this->testSuiteSize, count($suite));
+            $this->writeNewLine();
         }
 
         $this->lastEvent = self::EVENT_TESTSUITE_START;
@@ -522,14 +585,11 @@ class PHPUnit_TextUI_ResultPrinter extends PHPUnit_Util_Printer implements PHPUn
      */
     public function endTestSuite(PHPUnit_Framework_TestSuite $suite)
     {
+        $this->indent--;
+
         if ($this->verbose) {
-            array_pop($this->numberOfTests);
-            array_pop($this->testSuiteSize);
-
-            $this->column = 0;
-
             if ($this->lastEvent != self::EVENT_TESTSUITE_END) {
-                $this->write("\n");
+                $this->writeNewLine();
             }
         }
 
@@ -543,18 +603,6 @@ class PHPUnit_TextUI_ResultPrinter extends PHPUnit_Util_Printer implements PHPUn
      */
     public function startTest(PHPUnit_Framework_Test $test)
     {
-        if ($this->verbose) {
-            $this->numberOfTests[count($this->numberOfTests)-1]++;
-        }
-
-        else if (isset($this->numberOfTests[0])) {
-            $this->numberOfTests[0]++;
-        }
-
-        else {
-            $this->numberOfTests = array(1);
-        }
-
         $this->lastEvent = self::EVENT_TEST_START;
 
         if ($this->debug) {
@@ -564,6 +612,8 @@ class PHPUnit_TextUI_ResultPrinter extends PHPUnit_Util_Printer implements PHPUn
               )
             );
         }
+
+        $this->numTestsRun++;
     }
 
     /**
@@ -591,34 +641,34 @@ class PHPUnit_TextUI_ResultPrinter extends PHPUnit_Util_Printer implements PHPUn
      */
     protected function writeProgress($progress)
     {
-        $indent = max(0, count($this->testSuiteSize) - 1);
-
-        if ($this->column == 0) {
-            $this->write(str_repeat(' ', $indent));
-        }
-
         $this->write($progress);
+        $this->column++;
 
-        if ($this->column++ == 60 - 1 - $indent) {
-            if ($this->verbose) {
-                $numberOfTests = $this->numberOfTests[count($this->numberOfTests)-1];
-                $testSuiteSize = $this->testSuiteSize[count($this->testSuiteSize)-1];
-            } else {
-                $numberOfTests = $this->numberOfTests[0];
-                $testSuiteSize = $this->testSuiteSize[0];
+        if ($this->column == 60) {
+            if (!$this->verbose) {
+                $this->write(
+                  sprintf(
+                    ' %' . $this->numTestsWidth . 'd / %' . 
+                           $this->numTestsWidth . "d",
+
+                    $this->numTestsRun,
+                    $this->numTests
+                  )
+                );
             }
 
-            $width = strlen((string)$testSuiteSize);
+            $this->writeNewLine();
+        }
+    }
 
-            $this->write(
-              sprintf(
-                ' %' . $width . 'd / %' . $width . "d\n",
-
-                $numberOfTests,
-                $testSuiteSize
-              )
-            );
+    protected function writeNewLine()
+    {
+        $this->write("\n");
 
+        if ($this->verbose) {
+            $this->column = $this->indent;
+            $this->write(str_repeat(' ', max(0, $this->indent)));
+        } else {
             $this->column = 0;
         }
     }
