@@ -39,7 +39,7 @@
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: Report.php 4404 2008-12-31 09:27:18Z sb $
+ * @version    SVN: $Id: Report.php 5162 2009-08-29 08:49:43Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 3.0.0
  */
@@ -61,7 +61,7 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.3.16
+ * @version    Release: 3.4.5
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 3.0.0
  * @abstract
@@ -74,6 +74,7 @@ abstract class PHPUnit_Util_Report
      * Renders the report.
      *
      * @param  PHPUnit_Framework_TestResult $result
+     * @param  string                       $title
      * @param  string                       $target
      * @param  string                       $charset
      * @param  boolean                      $yui
@@ -81,7 +82,7 @@ abstract class PHPUnit_Util_Report
      * @param  integer                      $lowUpperBound
      * @param  integer                      $highLowerBound
      */
-    public static function render(PHPUnit_Framework_TestResult $result, $target, $charset = 'ISO-8859-1', $yui = TRUE, $highlight = FALSE, $lowUpperBound = 35, $highLowerBound = 70)
+    public static function render(PHPUnit_Framework_TestResult $result, $target, $title = '', $charset = 'ISO-8859-1', $yui = TRUE, $highlight = FALSE, $lowUpperBound = 35, $highLowerBound = 70)
     {
         $target = PHPUnit_Util_Filesystem::getDirectory($target);
 
@@ -95,16 +96,20 @@ abstract class PHPUnit_Util_Report
         );
 
         $codeCoverageInformation = $result->getCodeCoverageInformation();
-        $files                   = PHPUnit_Util_CodeCoverage::getSummary($codeCoverageInformation);
+        $files                   = PHPUnit_Util_CodeCoverage::getSummary(
+                                     $codeCoverageInformation
+                                   );
         $commonPath              = PHPUnit_Util_Filesystem::reducePaths($files);
         $items                   = self::buildDirectoryStructure($files);
 
         unset($codeCoverageInformation);
 
-        $topTestSuite = $result->topTestSuite();
+        if ($title == '') {
+            $topTestSuite = $result->topTestSuite();
 
-        if ($topTestSuite instanceof PHPUnit_Framework_TestSuite) {
-            $name = $topTestSuite->getName();
+            if ($topTestSuite instanceof PHPUnit_Framework_TestSuite) {
+                $title = $topTestSuite->getName();
+            }
         }
 
         unset($result);
@@ -118,7 +123,7 @@ abstract class PHPUnit_Util_Report
 
         $root->render(
           $target,
-          $name,
+          $title,
           $charset,
           $lowUpperBound,
           $highLowerBound
