@@ -39,7 +39,7 @@
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: Directory.php 4404 2008-12-31 09:27:18Z sb $
+ * @version    SVN: $Id: Directory.php 4993 2009-07-13 06:45:05Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 3.2.0
  */
@@ -60,7 +60,7 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.3.16
+ * @version    Release: 3.4.5
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 3.2.0
  */
@@ -104,7 +104,7 @@ class PHPUnit_Util_Report_Node_Directory extends PHPUnit_Util_Report_Node
     /**
      * @var    integer
      */
-    protected $numCalledClasses = -1;
+    protected $numTestedClasses = -1;
 
     /**
      * @var    integer
@@ -114,7 +114,7 @@ class PHPUnit_Util_Report_Node_Directory extends PHPUnit_Util_Report_Node
     /**
      * @var    integer
      */
-    protected $numCalledMethods = -1;
+    protected $numTestedMethods = -1;
 
     /**
      * Adds a new directory.
@@ -159,7 +159,7 @@ class PHPUnit_Util_Report_Node_Directory extends PHPUnit_Util_Report_Node
     /**
      * Returns the directories in this directory.
      *
-     * @return
+     * @return array
      */
     public function getDirectories()
     {
@@ -169,7 +169,7 @@ class PHPUnit_Util_Report_Node_Directory extends PHPUnit_Util_Report_Node
     /**
      * Returns the files in this directory.
      *
-     * @return
+     * @return array
      */
     public function getFiles()
     {
@@ -249,22 +249,21 @@ class PHPUnit_Util_Report_Node_Directory extends PHPUnit_Util_Report_Node
     }
 
     /**
-     * Returns the number of classes of which at least one method
-     * has been called at least once.
+     * Returns the number of tested classes.
      *
      * @return integer
      */
-    public function getNumCalledClasses()
+    public function getNumTestedClasses()
     {
-        if ($this->numCalledClasses == -1) {
-            $this->numCalledClasses = 0;
+        if ($this->numTestedClasses == -1) {
+            $this->numTestedClasses = 0;
 
             foreach ($this->children as $child) {
-                $this->numCalledClasses += $child->getNumCalledClasses();
+                $this->numTestedClasses += $child->getNumTestedClasses();
             }
         }
 
-        return $this->numCalledClasses;
+        return $this->numTestedClasses;
     }
 
     /**
@@ -286,21 +285,21 @@ class PHPUnit_Util_Report_Node_Directory extends PHPUnit_Util_Report_Node
     }
 
     /**
-     * Returns the number of methods that has been called at least once.
+     * Returns the number of tested methods.
      *
      * @return integer
      */
-    public function getNumCalledMethods()
+    public function getNumTestedMethods()
     {
-        if ($this->numCalledMethods == -1) {
-            $this->numCalledMethods = 0;
+        if ($this->numTestedMethods == -1) {
+            $this->numTestedMethods = 0;
 
             foreach ($this->children as $child) {
-                $this->numCalledMethods += $child->getNumCalledMethods();
+                $this->numTestedMethods += $child->getNumTestedMethods();
             }
         }
 
-        return $this->numCalledMethods;
+        return $this->numTestedMethods;
     }
 
     /**
