@@ -39,12 +39,13 @@
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: Skeleton.php 4404 2008-12-31 09:27:18Z sb $
+ * @version    SVN: $Id: Skeleton.php 5086 2009-08-11 15:36:19Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 2.1.0
  */
 
 require_once 'PHPUnit/Util/Filter.php';
+require_once 'PHPUnit/Util/Class.php';
 require_once 'PHPUnit/Util/Template.php';
 
 PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
@@ -57,38 +58,70 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.3.16
+ * @version    Release: 3.4.5
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 2.1.0
  */
 abstract class PHPUnit_Util_Skeleton
 {
     /**
-     * @var    string
+     * @var array
      */
     protected $inClassName;
 
     /**
-     * @var    string
+     * @var string
      */
     protected $inSourceFile;
 
     /**
-     * @var    string
+     * @var array
      */
     protected $outClassName;
 
     /**
-     * @var    string
+     * @var string
      */
     protected $outSourceFile;
 
+    /**
+     * Constructor.
+     *
+     * @param string $inClassName
+     * @param string $inSourceFile
+     * @param string $outClassName
+     * @param string $outSourceFile
+     * @since Method available since Release 3.4.0
+     */
+    public function __construct($inClassName, $inSourceFile = '', $outClassName = '', $outSourceFile = '')
+    {
+        $this->inClassName = PHPUnit_Util_Class::parseFullyQualifiedClassName(
+          $inClassName
+        );
+
+        $this->outClassName = PHPUnit_Util_Class::parseFullyQualifiedClassName(
+          $outClassName
+        );
+
+        $this->inSourceFile = str_replace(
+          $this->inClassName['fullyQualifiedClassName'],
+          $this->inClassName['className'],
+          $inSourceFile
+        );
+
+        $this->outSourceFile = str_replace(
+          $this->outClassName['fullyQualifiedClassName'],
+          $this->outClassName['className'],
+          $outSourceFile
+        );
+    }
+
     /**
      * @return string
      */
     public function getOutClassName()
     {
-        return $this->outClassName;
+        return $this->outClassName['fullyQualifiedClassName'];
     }
 
     /**
