@@ -39,7 +39,7 @@
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    SVN: $Id: NamePrettifier.php 4404 2008-12-31 09:27:18Z sb $
+ * @version    SVN: $Id: NamePrettifier.php 5162 2009-08-29 08:49:43Z sb $
  * @link       http://www.phpunit.de/
  * @since      File available since Release 2.3.0
  */
@@ -56,7 +56,7 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2009 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.3.16
+ * @version    Release: 3.4.5
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 2.1.0
  */
@@ -80,20 +80,20 @@ class PHPUnit_Util_TestDox_NamePrettifier
     /**
      * Prettifies the name of a test class.
      *
-     * @param  string  $testClassName
+     * @param  string  $name
      * @return string
      */
-    public function prettifyTestClass($testClassName)
+    public function prettifyTestClass($name)
     {
-        $title = $testClassName;
+        $title = $name;
 
         if ($this->suffix !== NULL &&
-            $this->suffix == substr($testClassName, -1 * strlen($this->suffix))) {
+            $this->suffix == substr($name, -1 * strlen($this->suffix))) {
             $title = substr($title, 0, strripos($title, $this->suffix));
         }
 
         if ($this->prefix !== NULL &&
-            $this->prefix == substr($testClassName, 0, strlen($this->prefix))) {
+            $this->prefix == substr($name, 0, strlen($this->prefix))) {
             $title = substr($title, strlen($this->prefix));
         }
 
@@ -103,43 +103,47 @@ class PHPUnit_Util_TestDox_NamePrettifier
     /**
      * Prettifies the name of a test method.
      *
-     * @param  string  $testMethodName
+     * @param  string  $name
      * @return string
      */
-    public function prettifyTestMethod($testMethodName)
+    public function prettifyTestMethod($name)
     {
         $buffer = '';
 
-        if (!is_string($testMethodName) || strlen($testMethodName) == 0) {
+        if (!is_string($name) || strlen($name) == 0) {
             return $buffer;
         }
 
-        $string = preg_replace('#\d+$#', '', $testMethodName);
+        $string = preg_replace('#\d+$#', '', $name);
 
         if (in_array($string, $this->strings)) {
-            $testMethodName = $string;
+            $name = $string;
         } else {
             $this->strings[] = $string;
         }
 
-        $max = strlen($testMethodName);
+        if (strpos($name, '_') !== FALSE) {
+            return str_replace('_', ' ', $name);
+        }
 
-        if (substr($testMethodName, 0, 4) == 'test') {
+        $max = strlen($name);
+
+        if (substr($name, 0, 4) == 'test') {
             $offset = 4;
         } else {
             $offset = 0;
-            $testMethodName[0] = strtoupper($testMethodName[0]);
+            $name[0] = strtoupper($name[0]);
         }
 
         $wasNumeric = FALSE;
 
         for ($i = $offset; $i < $max; $i++) {
             if ($i > $offset &&
-                ord($testMethodName[$i]) >= 65 &&
-                ord($testMethodName[$i]) <= 90) {
-                $buffer .= ' ' . strtolower($testMethodName[$i]);
+                ord($name[$i]) >= 65 &&
+                ord($name[$i]) <= 90) {
+                $buffer .= ' ' . strtolower($name[$i]);
             } else {
-                $isNumeric = is_numeric($testMethodName[$i]);
+                $isNumeric = is_numeric($name[$i]);
 
                 if (!$wasNumeric && $isNumeric) {
                     $buffer .= ' ';
@@ -150,7 +154,7 @@ class PHPUnit_Util_TestDox_NamePrettifier
                     $wasNumeric = FALSE;
                 }
 
-                $buffer .= $testMethodName[$i];
+                $buffer .= $name[$i];
             }
         }
 
